from Products.CMFCore.utils import getToolByName
from StringIO import StringIO

def changeAvailableViewsForFolder(self, templates, out):
    """Add new template view to the folder type"""

    types_tool = getToolByName(self, 'portal_types', None)
    if types_tool is not None:
        fti = getattr(types_tool, 'Folder', None)
        if fti is not None:
            try:
                views = fti.view_methods + templates
                fti.manage_changeProperties(view_methods=views)
                print >> out, "Added new view templates to Folder FTI."
            except:
                print >> out, "Adding new view templates to Folder FTI failed."


def changeListedTypesInNavigation(self, portal_types, out):
    """Change the list of portal_types listed in navigation tree"""
    
    props_tool = getToolByName(self, 'portal_properties', None)
    if props_tool is not None:
        navprops = props_tool.navtree_properties
        if navprops is not None:
            try:
                notListed = navprops.getProperty('metaTypesNotToList') + ('SCAuditoriumItem',)
                navprops.manage_changeProperties(metaTypesNotToList=notListed)
                print >> out, "Portal types listed in navigation tree updated."
            except:
                print >> out, "Updating of portal types listed in navigation tree failed."


def undoAvailableViewsForFolder(self, templates, out):
    """Undo: Add new template view to the folder type"""

    types_tool = getToolByName(self, 'portal_types', None)
    if types_tool is not None:
        fti = getattr(types_tool, 'Folder', None)
        if fti is not None:
            try:
                source = fti.view_methods
                views = []
                for view in source:
                    if view not in templates:
                        views.append(view)                                    
                fti.manage_changeProperties(view_methods=tuple(views))
                print >> out, "Removed Auditorium view templates from Folder FTI."
            except:
                print >> out, "Removing Auditorium view templates from Folder FTI failed."


def install(self):
    """ Custom External Method to install SCAuditorium """

    out = StringIO()

    # grouping template registration
    changeAvailableViewsForFolder(self, ('scauditorium_folder',), out)

    # remove auditorium item from portal types listed in navigation tree
    changeListedTypesInNavigation(self, ('SCAuditoriumItem',), out)
  
    # make new types use portal_factory
    ft = getToolByName(self, 'portal_factory')
    portal_factory_types = ft.getFactoryTypes().keys()
    for t in ['SCAuditorium'
             ,'SCAuditoriumItem']: 

        if t not in portal_factory_types:
            portal_factory_types.append(t)
            ft.manage_setPortalFactoryTypes(listOfTypeIds=portal_factory_types)
            
    print >> out, 'New types use portal_factory'


def uninstall(self):
    """ Custom External Method to uninstall SCAuditorium """

    out = StringIO()

    # grouping template unregistration
    undoAvailableViewsForFolder(self, ('scauditorium_folder',), out)
