"""Workflow: scauditorium_workflow
"""

# Copyright (c) 2005 by SureCase.org
#

# Generator: ArchGenXML Version 1.4 devel 4
#            http://sf.net/projects/archetypes/
#
# GNU General Public Licence (GPL)
# 
# This program is free software; you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation; either version 2 of the License, or (at your option) any later
# version.
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
# details.
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc., 59 Temple
# Place, Suite 330, Boston, MA  02111-1307  USA
#
__author__    = '''SureCase.org <info@surecase.org>'''
__docformat__ = 'plaintext'
__version__   = '$ Revision 0.0 $'[11:-2]

from Products.CMFCore.utils import getToolByName
from Products.CMFCore.WorkflowTool import addWorkflowFactory
from Products.DCWorkflow.DCWorkflow import DCWorkflowDefinition
from Products.ExternalMethod.ExternalMethod import ExternalMethod

##code-section create-workflow-module-header #fill in your manual code here
##/code-section create-workflow-module-header


productname = 'SCAuditorium'

def setupscauditorium_workflow(self, workflow):
    """Define the scauditorium_workflow workflow.
    """

    workflow.setProperties(title='scauditorium_workflow')

    ##code-section create-workflow-setup-method-header #fill in your manual code here
    ##/code-section create-workflow-setup-method-header


    for s in ['private', 'published', 'members', 'closed', 'customized']:
        workflow.states.addState(s)

    for t in ['customize', 'close', 'protect', 'open', 'retrieve']:
        workflow.transitions.addTransition(t)

    for v in ['review_history', 'comments', 'time', 'actor', 'action']:
        workflow.variables.addVariable(v)

    for p in ['Access contents information', 'Modify portal content', 'View', 'SCAuditorium: Post items', 'Add portal content']:
        workflow.addManagedPermission(p)
 
    for l in []:
        if not l in workflow.worklists.objectValues():
            workflow.worklists.addWorklist(l)

    ## Initial State

    workflow.states.setInitialState('private')

    ## States initialization

    stateDef = workflow.states['private']
    stateDef.setProperties(title="""private""",
                           transitions=['open', 'protect', 'customize'])
    stateDef.setPermission('Access contents information',
                           0,
                           ['Manager', 'Owner'])
    stateDef.setPermission('Modify portal content',
                           0,
                           ['Manager', 'Owner'])
    stateDef.setPermission('View',
                           0,
                           ['Manager', 'Owner'])
    stateDef.setPermission('SCAuditorium: Post items',
                           0,
                           ['Manager'])
    stateDef.setPermission('Add portal content',
                           0,
                           ['Manager'])

    stateDef = workflow.states['published']
    stateDef.setProperties(title="""published""",
                           transitions=['close', 'protect', 'customize'])
    stateDef.setPermission('Access contents information',
                           0,
                           ['Anonymous', 'Manager'])
    stateDef.setPermission('Modify portal content',
                           0,
                           ['Manager', 'Reviewer'])
    stateDef.setPermission('View',
                           0,
                           ['Anonymous', 'Manager'])
    stateDef.setPermission('SCAuditorium: Post items',
                           0,
                           ['Manager', 'Member'])
    stateDef.setPermission('Add portal content',
                           0,
                           ['Manager', 'Member'])

    stateDef = workflow.states['members']
    stateDef.setProperties(title="""members""",
                           transitions=['close', 'open', 'customize'])
    stateDef.setPermission('Access contents information',
                           0,
                           ['Manager', 'Member'])
    stateDef.setPermission('Modify portal content',
                           0,
                           ['Manager', 'Reviewer'])
    stateDef.setPermission('View',
                           0,
                           ['Manager', 'Member'])
    stateDef.setPermission('SCAuditorium: Post items',
                           0,
                           ['Manager', 'Member'])
    stateDef.setPermission('Add portal content',
                           0,
                           ['Manager', 'Member'])

    stateDef = workflow.states['closed']
    stateDef.setProperties(title="""closed""",
                           transitions=['retrieve'])
    stateDef.setPermission('Access contents information',
                           0,
                           ['Manager', 'Owner'])
    stateDef.setPermission('Modify portal content',
                           0,
                           ['Manager', 'Owner'])
    stateDef.setPermission('View',
                           0,
                           ['Manager', 'Owner'])
    stateDef.setPermission('SCAuditorium: Post items',
                           0,
                           ['Manager'])
    stateDef.setPermission('Add portal content',
                           0,
                           ['Manager'])

    stateDef = workflow.states['customized']
    stateDef.setProperties(title="""customized""",
                           transitions=['close', 'protect', 'open'])
    stateDef.setPermission('Access contents information',
                           0,
                           ['Manager', 'Owner'])
    stateDef.setPermission('Modify portal content',
                           0,
                           ['Manager', 'Owner'])
    stateDef.setPermission('View',
                           0,
                           ['Manager', 'Owner'])
    stateDef.setPermission('SCAuditorium: Post items',
                           0,
                           ['Manager', 'Owner'])
    stateDef.setPermission('Add portal content',
                           0,
                           ['Manager', 'Owner'])

    ## Transitions initialization

    transitionDef = workflow.transitions['customize']
    transitionDef.setProperties(title="""customize""",
                                new_state_id="""customized""",
                                trigger_type=1,
                                script_name="""""",
                                after_script_name="""""",
                                actbox_name="""customize""",
                                actbox_url="""""",
                                actbox_category="""workflow""",
                                props={'guard_permissions': 'Request review'},
                                )

    transitionDef = workflow.transitions['close']
    transitionDef.setProperties(title="""close""",
                                new_state_id="""closed""",
                                trigger_type=1,
                                script_name="""""",
                                after_script_name="""""",
                                actbox_name="""close""",
                                actbox_url="""""",
                                actbox_category="""workflow""",
                                props={'guard_permissions': 'Review portal content', 'guard_roles': 'Manager;Owner'},
                                )

    transitionDef = workflow.transitions['protect']
    transitionDef.setProperties(title="""protect""",
                                new_state_id="""members""",
                                trigger_type=1,
                                script_name="""""",
                                after_script_name="""""",
                                actbox_name="""protect""",
                                actbox_url="""""",
                                actbox_category="""workflow""",
                                props={'guard_permissions': 'Request review'},
                                )

    transitionDef = workflow.transitions['open']
    transitionDef.setProperties(title="""open""",
                                new_state_id="""published""",
                                trigger_type=1,
                                script_name="""""",
                                after_script_name="""""",
                                actbox_name="""open""",
                                actbox_url="""""",
                                actbox_category="""workflow""",
                                props={'guard_permissions': 'Request review'},
                                )

    transitionDef = workflow.transitions['retrieve']
    transitionDef.setProperties(title="""retrieve""",
                                new_state_id="""private""",
                                trigger_type=1,
                                script_name="""""",
                                after_script_name="""""",
                                actbox_name="""retrieve""",
                                actbox_url="""""",
                                actbox_category="""workflow""",
                                props={'guard_permissions': 'Review portal content', 'guard_roles': 'Manager;Owner'},
                                )

    ## State Variable
    workflow.variables.setStateVar('review_state')

    ## Variables initialization
    variableDef = workflow.variables['review_history']
    variableDef.setProperties(description="""Provides access to workflow history""",
                              default_value="""""",
                              default_expr="""state_change/getHistory""",
                              for_catalog=0,
                              for_status=0,
                              update_always=0,
                              props={'guard_permissions': 'Request review; Review portal content'})

    variableDef = workflow.variables['comments']
    variableDef.setProperties(description="""Comments about the last transition""",
                              default_value="""""",
                              default_expr="""python:state_change.kwargs.get('comment', '')""",
                              for_catalog=0,
                              for_status=1,
                              update_always=1,
                              props=None)

    variableDef = workflow.variables['time']
    variableDef.setProperties(description="""Time of the last transition""",
                              default_value="""""",
                              default_expr="""state_change/getDateTime""",
                              for_catalog=0,
                              for_status=1,
                              update_always=1,
                              props=None)

    variableDef = workflow.variables['actor']
    variableDef.setProperties(description="""The ID of the user who performed the last transition""",
                              default_value="""""",
                              default_expr="""user/getId""",
                              for_catalog=0,
                              for_status=1,
                              update_always=1,
                              props=None)

    variableDef = workflow.variables['action']
    variableDef.setProperties(description="""The last transition""",
                              default_value="""""",
                              default_expr="""transition/getId|nothing""",
                              for_catalog=0,
                              for_status=1,
                              update_always=1,
                              props=None)

    ## Worklists Initialization


    # WARNING: below protected section is deprecated.
    # Add a tagged value 'worklist' with the worklist name to your state(s) instead.
    ##code-section create-workflow-setup-method-footer #fill in your manual code here
    ##/code-section create-workflow-setup-method-footer



def createscauditorium_workflow(self, id):
    """Create the workflow for SCAuditorium.
    """
    
    ob = DCWorkflowDefinition(id)
    setupscauditorium_workflow(self, ob)
    return ob

addWorkflowFactory(createscauditorium_workflow,
                   id='scauditorium_workflow',
                   title='scauditorium_workflow')

##code-section create-workflow-module-footer #fill in your manual code here
##/code-section create-workflow-module-footer

