"""Workflow: scauditoriumitem_workflow
"""

# Copyright (c) 2005 by SureCase.org
#

# Generator: ArchGenXML Version 1.4 devel 4
#            http://sf.net/projects/archetypes/
#
# GNU General Public Licence (GPL)
# 
# This program is free software; you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation; either version 2 of the License, or (at your option) any later
# version.
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
# details.
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc., 59 Temple
# Place, Suite 330, Boston, MA  02111-1307  USA
#
__author__    = '''SureCase.org <info@surecase.org>'''
__docformat__ = 'plaintext'
__version__   = '$ Revision 0.0 $'[11:-2]

from Products.CMFCore.utils import getToolByName
from Products.CMFCore.WorkflowTool import addWorkflowFactory
from Products.DCWorkflow.DCWorkflow import DCWorkflowDefinition
from Products.ExternalMethod.ExternalMethod import ExternalMethod

##code-section create-workflow-module-header #fill in your manual code here
##/code-section create-workflow-module-header


productname = 'SCAuditorium'

def setupscauditoriumitem_workflow(self, workflow):
    """Define the scauditoriumitem_workflow workflow.
    """
    # add additional roles to portal
    portal = getToolByName(self,'portal_url').getPortalObject()
    data = list(portal.__ac_roles__)
    for role in ['AModerator']:
        if not role in self.__ac_roles__:
            data.append(role)
    portal.__ac_roles__ = tuple(data)

    workflow.setProperties(title='scauditoriumitem_workflow')

    ##code-section create-workflow-setup-method-header #fill in your manual code here
    ##/code-section create-workflow-setup-method-header


    for s in ['posted', 'approved', 'rejected', 'disabled']:
        workflow.states.addState(s)

    for t in ['enable', 'disable', 'approve', 'refresh', 'reject']:
        workflow.transitions.addTransition(t)

    for v in ['review_history', 'comments', 'time', 'actor', 'action']:
        workflow.variables.addVariable(v)

    for p in ['Access contents information', 'Modify portal content', 'View']:
        workflow.addManagedPermission(p)
 
    for l in []:
        if not l in workflow.worklists.objectValues():
            workflow.worklists.addWorklist(l)

    ## Initial State

    workflow.states.setInitialState('posted')

    ## States initialization

    stateDef = workflow.states['posted']
    stateDef.setProperties(title="""posted""",
                           transitions=['approve', 'reject', 'disable'])
    stateDef.setPermission('Access contents information',
                           0,
                           ['Manager', 'Anonymous'])
    stateDef.setPermission('Modify portal content',
                           0,
                           ['Manager', 'Owner'])
    stateDef.setPermission('View',
                           0,
                           ['Manager', 'Anonymous'])

    stateDef = workflow.states['approved']
    stateDef.setProperties(title="""approved""",
                           transitions=['reject'])
    stateDef.setPermission('Access contents information',
                           0,
                           ['Manager', 'Anonymous'])
    stateDef.setPermission('Modify portal content',
                           0,
                           ['Manager'])
    stateDef.setPermission('View',
                           0,
                           ['Manager', 'Anonymous'])

    stateDef = workflow.states['rejected']
    stateDef.setProperties(title="""rejected""",
                           transitions=['refresh', 'approve', 'disable'])
    stateDef.setPermission('Access contents information',
                           0,
                           ['Manager', 'AModerator', 'Owner'])
    stateDef.setPermission('Modify portal content',
                           0,
                           ['Manager', 'Owner'])
    stateDef.setPermission('View',
                           0,
                           ['Manager', 'AModerator', 'Owner'])

    stateDef = workflow.states['disabled']
    stateDef.setProperties(title="""disabled""",
                           transitions=['enable'])
    stateDef.setPermission('Access contents information',
                           0,
                           ['Manager', 'AModerator'])
    stateDef.setPermission('Modify portal content',
                           0,
                           ['Manager'])
    stateDef.setPermission('View',
                           0,
                           ['Manager', 'AModerator'])

    ## Transitions initialization

    transitionDef = workflow.transitions['enable']
    transitionDef.setProperties(title="""enable""",
                                new_state_id="""rejected""",
                                trigger_type=1,
                                script_name="""""",
                                after_script_name="""""",
                                actbox_name="""enable""",
                                actbox_url="""""",
                                actbox_category="""workflow""",
                                props={'guard_roles': 'Manager;AModerator'},
                                )

    transitionDef = workflow.transitions['disable']
    transitionDef.setProperties(title="""disable""",
                                new_state_id="""disabled""",
                                trigger_type=1,
                                script_name="""""",
                                after_script_name="""""",
                                actbox_name="""disable""",
                                actbox_url="""""",
                                actbox_category="""workflow""",
                                props={'guard_roles': 'Manager;AModerator;Owner'},
                                )

    transitionDef = workflow.transitions['approve']
    transitionDef.setProperties(title="""approve""",
                                new_state_id="""approved""",
                                trigger_type=1,
                                script_name="""""",
                                after_script_name="""""",
                                actbox_name="""approve""",
                                actbox_url="""""",
                                actbox_category="""workflow""",
                                props={'guard_roles': 'Manager;AModerator'},
                                )

    transitionDef = workflow.transitions['refresh']
    transitionDef.setProperties(title="""refresh""",
                                new_state_id="""posted""",
                                trigger_type=1,
                                script_name="""""",
                                after_script_name="""""",
                                actbox_name="""refresh""",
                                actbox_url="""""",
                                actbox_category="""workflow""",
                                props={'guard_roles': 'Manager;AModerator;Owner'},
                                )

    transitionDef = workflow.transitions['reject']
    transitionDef.setProperties(title="""reject""",
                                new_state_id="""rejected""",
                                trigger_type=1,
                                script_name="""""",
                                after_script_name="""""",
                                actbox_name="""reject""",
                                actbox_url="""""",
                                actbox_category="""workflow""",
                                props={'guard_roles': 'Manager;AModerator'},
                                )

    ## State Variable
    workflow.variables.setStateVar('review_state')

    ## Variables initialization
    variableDef = workflow.variables['review_history']
    variableDef.setProperties(description="""Provides access to workflow history""",
                              default_value="""""",
                              default_expr="""state_change/getHistory""",
                              for_catalog=0,
                              for_status=0,
                              update_always=0,
                              props={'guard_permissions': 'Request review; Review portal content'})

    variableDef = workflow.variables['comments']
    variableDef.setProperties(description="""Comments about the last transition""",
                              default_value="""""",
                              default_expr="""python:state_change.kwargs.get('comment', '')""",
                              for_catalog=0,
                              for_status=1,
                              update_always=1,
                              props=None)

    variableDef = workflow.variables['time']
    variableDef.setProperties(description="""Time of the last transition""",
                              default_value="""""",
                              default_expr="""state_change/getDateTime""",
                              for_catalog=0,
                              for_status=1,
                              update_always=1,
                              props=None)

    variableDef = workflow.variables['actor']
    variableDef.setProperties(description="""The ID of the user who performed the last transition""",
                              default_value="""""",
                              default_expr="""user/getId""",
                              for_catalog=0,
                              for_status=1,
                              update_always=1,
                              props=None)

    variableDef = workflow.variables['action']
    variableDef.setProperties(description="""The last transition""",
                              default_value="""""",
                              default_expr="""transition/getId|nothing""",
                              for_catalog=0,
                              for_status=1,
                              update_always=1,
                              props=None)

    ## Worklists Initialization


    # WARNING: below protected section is deprecated.
    # Add a tagged value 'worklist' with the worklist name to your state(s) instead.
    ##code-section create-workflow-setup-method-footer #fill in your manual code here
    ##/code-section create-workflow-setup-method-footer



def createscauditoriumitem_workflow(self, id):
    """Create the workflow for SCAuditorium.
    """
    
    ob = DCWorkflowDefinition(id)
    setupscauditoriumitem_workflow(self, ob)
    return ob

addWorkflowFactory(createscauditoriumitem_workflow,
                   id='scauditoriumitem_workflow',
                   title='scauditoriumitem_workflow')

##code-section create-workflow-module-footer #fill in your manual code here
##/code-section create-workflow-module-footer

